/**
 * Copyright (c) 2011 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

/**
 * @file analog.cpp
 * @brief Contains code to read analog data.
 *
 * Implementation of functions for analog use.
 *
 * @author Colony Project, CMU Robotics Club
 * @author Dev Gurjar
 **/

#include <ros/ros.h>

#include "analog.h"

/**
 * @defgroup analog Analog
 * @brief Functions for reading analog input
 *
 * @{
 **/

/* Analog state variables */
/** @todo Fix types: static */
unsigned int port; /**< The current port from which we are reading from. */

/**
 * @brief Outputs current analog data at a given port
 *
 * Serves the service query_analog by responding to service requests with the
 * speeds of the motors.
 * @param req The request. The only field is the units requested.
 * @param res The response. The fields will be filled with values.
 */
bool analog_query(analog::query_analog::Request &req,
                  analog::query_analog::Response &res)
{
    int port = req.port;
    res.sensor_data = get_sensor_data(port);

    ROS_DEBUG("Analog data queried");
    return true;
}

/* 
 * @brief 
 *
 * Given a port number, returns the analog data present at the port
 * 
 * @param port The port we want to read from
 */
unsigned int get_sensor_data(int port)
{
    ROS_DEBUG("Got Analog data from the sensor [Unimplemented]");
    return 0;
}

/**
 * @brief Analog driver. Provides an interface to read data from analog ports.
 */
int main(int argc, char **argv)
{
    /* Initialize in ROS the motors driver node */
    ros::init(argc, argv, "analog_driver");

    /* Advertise that this serves the query_analog service */
    ros::NodeHandle n;
    ros::ServiceServer service = n.advertiseService("query_analog",
                                                    analog_query);

    /* Initialize hardware for analog */

    // Hardware init functions here
    ros::spin();

    return 0;
}

/** @} **/
