/**
 * Copyright (c) 2011 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

/**
 * @file usb_serial.cpp
 * @brief USB_Serial
 *
 * Implementation of functions for USB/Serial use.
 *
 * @author Colony Project, CMU Robotics Club
 * @author Lalitha Ganesan
 **/

#include <ros/ros.h>

#include "usb_serial.h"

/**
 * @defgroup usb_serial USB_Serial
 * @brief Functions for using the USB/Serial Ports
 *
 * @{
 **/

/* USB/Serial state variables */
int data; /**< The USB serial data received. */
//int num_data_bits; /**< The number of bits that store data. */
//int num_stop_bits; /**< The number of bits that indicate the end of data. */
//int parity_type; /**< The parity type of the data being sent over. */
//int baud_rate; /**< The baud rate of the USB/Serial (bits/sec). */

/**
 * @brief Sends USB/Serial data.
 *
 * Sets the state vars based on subscription to the serial_data_out topic.
 */
void send_serial_data(const usb_serial::serial_data::ConstPtr& msg)
{
    data = msg->data;
    //num_data_bits = msg->num_data_bits;
    //num_stop_bits = msg->num_stop_bits;
    //parity_type = msg->parity_type;
    //baud_rate = msg->baud_rate;

    // Write the data to hardware here
}

/**
 * @brief USB_Serial driver. This is a ROS node that controls USB/Serial 
 *        port data.
 *
 * This is the main function for the usb_serial node. It is run when the node
 * starts and initializes USB/Serial ports. It then subscribes to the
 * serial_data_out topic, and publishes to the serial_data_in message.
 */
int main(int argc, char **argv)
{
    /* Initialize in ROS the usb_serial driver node */
    ros::init(argc, argv, "usb_serial_driver");

    ros::NodeHandle n;

    /* Subscribe to the topic of outgoing serial data (which will be written
     * to the hardware) and if we receive any, send it via serial_data_out. */
    ros::Subscriber sub = n.subscribe("serial_data_out",
                                      QUEUE_SIZE, send_serial_data);

    /* Publish ingoing serial data messages back to the library. As part of
     * its main() function, this node reads hardware data and if a new
     * serial message is found, this publisher sends it inbound over ROS */
    ros::Publisher pub = n.advertise<usb_serial::serial_data>("serial_data_in",                                                               QUEUE_SIZE);

    // Initialize hardware for USB/Serial ports

    ROS_INFO("Ready to set USB/Serial. [Unimplemented]");

    // Get and publish serial data here.

    ros::spin();

    return 0;
}

/** @} */

